@@ -17,8 +17,8 @@ package Dist::Zilla::Plugin::GitVersionCheckCJM;
 # ABSTRACT: Ensure version numbers are up-to-date
 #---------------------------------------------------------------------
 
-our $VERSION = '3.02';
-# This file is part of Dist-Zilla-Plugins-CJM 3.04 (December 20, 2010)
+our $VERSION = '4.00';
+# This file is part of Dist-Zilla-Plugins-CJM 4.00 (November 1, 2011)
 
 
 use version 0.77 ();
@@ -33,7 +33,8 @@ with(
 );
 
 
-use Git::Wrapper ();
+# RECOMMEND PREREQ: Git::Wrapper
+use Git::Wrapper ();            # AutoPrereqs skips this
 
 #---------------------------------------------------------------------
 # Helper sub to run a git command and split on NULs:
@@ -61,7 +62,7 @@ sub munge_files {
   my %released = map { /^v?([\d._]+)$/ ? ($1, 1) : () } $git->tag;
 
   # Get the list of modified but not-checked-in files:
-  my %modified = map { $_ => 1 } (
+  my %modified = map { $self->log_debug("mod: $_"); $_ => 1 } (
     # Files that need to be committed:
     _git0($git, qw( diff_index -z HEAD --name-only )),
     # Files that are not tracked by git yet:
@@ -89,6 +90,7 @@ sub munge_file
 
   # Extract information from the module:
   my $pmFile  = $file->name;
+  $self->log_debug("checking $pmFile");
   my $pm_info = $self->get_module_info($file);
 
   my $version = $pm_info->version
@@ -158,9 +160,9 @@ Dist::Zilla::Plugin::GitVersionCheckCJM - Ensure version numbers are up-to-date
 
 =head1 VERSION
 
-This document describes version 3.02 of
-Dist::Zilla::Plugin::GitVersionCheckCJM, released December 20, 2010
-as part of Dist-Zilla-Plugins-CJM version 3.04.
+This document describes version 4.00 of
+Dist::Zilla::Plugin::GitVersionCheckCJM, released November 1, 2011
+as part of Dist-Zilla-Plugins-CJM version 4.00.
 
 =head1 SYNOPSIS
 
@@ -211,7 +213,7 @@ listed any number of times.
 
 =head1 DEPENDENCIES
 
-GitVersionCheckCJM requires L<Dist::Zilla> (3 or later).
+GitVersionCheckCJM requires L<Dist::Zilla> (4 or later).
 It also requires L<Git::Wrapper>, although it
 is only listed as a recommended dependency for the distribution (to
 allow people who don't use Git to use the other plugins.)
@@ -228,17 +230,17 @@ No bugs have been reported.
 
 Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
-Please report any bugs or feature requests to
-S<C<< <bug-Dist-Zilla-Plugins-CJM AT rt.cpan.org> >>>,
+Please report any bugs or feature requests
+to S<C<< <bug-Dist-Zilla-Plugins-CJM AT rt.cpan.org> >>>
 or through the web interface at
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM>
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM >>.
 
 You can follow or contribute to Dist-Zilla-Plugins-CJM's development at
 L<< http://github.com/madsen/dist-zilla-plugins-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Christopher J. Madsen.
+This software is copyright (c) 2011 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
