@@ -18,7 +18,7 @@ package Dist::Zilla::Plugin::Metadata;
 #---------------------------------------------------------------------
 
 our $VERSION = '3.03';
-# This file is part of Dist-Zilla-Plugins-CJM 3.05 (May 5, 2011)
+# This file is part of Dist-Zilla-Plugins-CJM 4.00 (November 1, 2011)
 
 
 use Moose;
@@ -79,8 +79,8 @@ Dist::Zilla::Plugin::Metadata - Add arbitrary keys to distmeta
 =head1 VERSION
 
 This document describes version 3.03 of
-Dist::Zilla::Plugin::Metadata, released May 5, 2011
-as part of Dist-Zilla-Plugins-CJM version 3.05.
+Dist::Zilla::Plugin::Metadata, released November 1, 2011
+as part of Dist-Zilla-Plugins-CJM version 4.00.
 
 =head1 SYNOPSIS
 
@@ -110,7 +110,7 @@ Dist::Zilla::Plugin::Metadata requires no configuration files or environment var
 
 =head1 DEPENDENCIES
 
-Metadata requires L<Dist::Zilla> (3 or later).
+Metadata requires L<Dist::Zilla> (4 or later).
 
 =head1 INCOMPATIBILITIES
 
@@ -124,10 +124,10 @@ No bugs have been reported.
 
 Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
 
-Please report any bugs or feature requests to
-S<C<< <bug-Dist-Zilla-Plugins-CJM AT rt.cpan.org> >>>,
+Please report any bugs or feature requests
+to S<C<< <bug-Dist-Zilla-Plugins-CJM AT rt.cpan.org> >>>
 or through the web interface at
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM>
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugins-CJM >>.
 
 You can follow or contribute to Dist-Zilla-Plugins-CJM's development at
 L<< http://github.com/madsen/dist-zilla-plugins-cjm >>.
